#! /bin/bash

CONFFILE=/usr/local/etc/qmrtg.conf

########### don't edit below ####################

 # called when something is wrong on the command line
function usage() {
    echo "Usage:"
    echo "`basename $0` query_type"
    echo "see qmrtg(1) for details."
}


# if ( $1 > $VERBOSITY_LEVEL ) then log $2
function debug() {
    local ISSUED_LEVEL=$1
    
    [ "$VERBOSITYLEVEL" -ge "$ISSUED_LEVEL" ] && { echo >>"$DEBUG" ; echo $2 >>"$DEBUG" ; }
}


 # called for each log file to be parsed
 # $1 = the logfile
function qmrtgparse() {
    local LOGFILE=$1

    debug 2 "$COMMAND: have to check logfile $LOGFILE"
    debug 2 "$COMMAND: Calling $COMMAND (after $LASTENTRY) on $LOGFILE"

     # skipping useless "0" lines
    RETV=`cat "$LOGFILE" | $QFILT "$LASTENTRY" | eval "$COMMAND" 2>>$DEBUG`
    [ -z "$RETV" ] && { debug 1 "$COMMAND: No output from $COMMAND"; return ; }  || debug 1 "$COMMAND: $COMMAND returns: $RETV"
    NEWTIMESTAMP=`tail -1 "$LOGFILE" | $QTAIF` # Yes, this could loose a trascurable number of log lines on busy server activity
    # have a look if the module provided a timestamp of its own (3rd line output non-empty)
    [ "`echo $RETV | awk '{ print $3 }'`" ] && NEWTIMESTAMP=`echo $RETV | awk '{ print $3 }'`
    debug 1 "$COMMAND: updating timestamp to: $NEWTIMESTAMP"
    updateTimestamp $NEWTIMESTAMP

     # the first line output is the # of remote deliveries
    OUTPUT1=$(( $OUTPUT1 + `echo $RETV | awk '{ print $1 }'` ))
    debug 2 "$COMMAND: from file $1: `echo $RETV | awk '{ print $1 }'` entries found. Current total: $OUTPUT1"
     # the second line output is the # of local deliveries
    OUTPUT2=$(( $OUTPUT2 + `echo $RETV | awk '{ print $2 }'` ))
    debug 2 "$COMMAND: from file $1: `echo $RETV | awk '{ print $2 }'` entries found. Current total: $OUTPUT2"
}


 # updates the timestamp entry to the one of the last line analyzed 
function updateTimestamp() {
    [ "$1" ] || return;
    echo $1 > $QMRTG_DBPATH/$DBFILE
    
    debug 3 "$COMMAND: timestamp called for: $1 ; timestamp from db: `cat $QMRTG_DBPATH/$DBFILE`"
}



function qmrtgLoadLastEntry() {

    [ -f "$QMRTG_DBPATH/$DBFILE" ] || { echo "000000000000000000000000" ; debug 1 "$COMMAND: dbfile $QMRTG_DBPATH/$DBFILE does not exist. Reporting from time 0." ; return ; }
    echo `cat $QMRTG_DBPATH/$DBFILE`
}


 # checking for sane call
[ -z "$1" ] && { usage ; exit 1; } 

 # loads settings from the config file, if it exists
[ -f "$CONFFILE" ] && . $CONFFILE

debug 1 "\*\*\*\*\*  session started - `date` -   \*\*\*\*\*"

DBFILE=$1.last
OUTPUT1=0
OUTPUT2=0

 # checking the query type argument
for (( i=1; $i <= ${#AVAILCMDS[*]}; $((i++)) )) ;
do 
    [ "$1" = "${AVAILCMDS[$i]}" ] && { COMMAND=${ACTUALCMDS[$i]} ; break; }
done

 # the "type" specified is not known from $CONFFILE
[ -z "$COMMAND" ] && {
    echo "Error. \"type\" must be one of:"
    for (( i=1; $i <= ${#AVAILCMDS[*]}; $((i++)) )) ;
    do
            echo "-> ${AVAILCMDS[$i]}"
    done
    echo "--"
    echo "Have a look at $CONFFILE. Terminating."
    exit 1
}


debug 3 "query: $1 - then command: $COMMAND"


 # checking the logdir argument
LOGDIR=${LOGDIRS[$i]}
[ -d "$LOGDIR" -a -r "${LOGDIR}/current" ] || { echo "Unable to access $LOGDIR, target for $COMMAND. Terminating." ; exit 2; }

debug 3 "$COMMAND: log directory: $LOGDIR"

[ -z "$QMRTG_DBPATH" ] && exit 1

debug 2 "$COMMAND: database directory: $QMRTG_DBPATH"




# this is main()


fileslist=`ls $LOGDIR/@*`

debug 6 "$COMMAND: files to scan (excluding \"current\"): $fileslist"

LASTENTRY=`qmrtgLoadLastEntry` 
for i in $fileslist ; do {
    foo=`basename $i | $QTAIF`
    [ "$LASTENTRY" '<' "$foo" ] && qmrtgparse "$i"
}; done

debug 1 "$COMMAND: scanning for \"current\""

 # finally unconditionally parse the last logfile "current"
qmrtgparse "$LOGDIR/current"

if ( [ ! -z "$OUTPUT1" ] ) ; then {
    echo $OUTPUT1
    debug 1 "$COMMAND: grand total1: $OUTPUT1"
} else {
    echo 0
    debug 1 "$COMMAND: HEI!!! The first output value is empty!!"
}; fi

if ( [ ! -z "$OUTPUT2" ] ); then {
    echo $OUTPUT2
    debug 1 "$COMMAND: grand total2: $OUTPUT2"
} else {
    echo 0
    debug 1 "$COMMAND: HEI!!! The second output value is empty!!"
}; fi 

echo `uptime | awk -F',' '{ print $1 }'`
echo `hostname`
